#[non_exhaustive]pub struct StartGeneratedCodeJobInput {
pub game_name: Option<String>,
pub snapshot_id: Option<String>,
pub generator: Option<Generator>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.game_name: Option<String>The name of the game.
snapshot_id: Option<String>The identifier of the snapshot for which to generate code.
generator: Option<Generator>Properties of the generator to use for the job.
Implementations
Sourceimpl StartGeneratedCodeJobInput
impl StartGeneratedCodeJobInput
Sourcepub fn builder() -> StartGeneratedCodeJobInputBuilder
pub fn builder() -> StartGeneratedCodeJobInputBuilder
Creates a new builder-style object to manufacture StartGeneratedCodeJobInput.